@@ -6,12 +6,12 @@ from ..Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class FirmwareUpdate:
-	"""FirmwareUpdate commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""
+class FirmwareUpdateCls:
+	"""FirmwareUpdate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
-		self._base = CommandsGroup("firmwareUpdate", core, parent)
+		self._cmd_group = CommandsGroup("firmwareUpdate", core, parent)
 
 	def get_versions(self) -> List[str]:
 		"""SCPI: FETCh:FWUPdate:VERSions \n
