@@ -5,12 +5,12 @@ from ..Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Get:
-	"""Get commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""
+class GetCls:
+	"""Get commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
-		self._base = CommandsGroup("get", core, parent)
+		self._cmd_group = CommandsGroup("get", core, parent)
 
 	def get_xvalues(self) -> List[float]:
 		"""SCPI: GET:XVALues \n
