@@ -5,12 +5,12 @@ from ..Internal.Utilities import trim_str_response
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Procedure:
-	"""Procedure commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""
+class ProcedureCls:
+	"""Procedure commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
-		self._base = CommandsGroup("procedure", core, parent)
+		self._cmd_group = CommandsGroup("procedure", core, parent)
 
 	def get_cmwd(self) -> str:
 		"""SCPI: PROCedure:CMWD \n
