@@ -4,12 +4,12 @@ from ..Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class RecallState:
-	"""RecallState commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""
+class RecallStateCls:
+	"""RecallState commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
-		self._base = CommandsGroup("recallState", core, parent)
+		self._cmd_group = CommandsGroup("recallState", core, parent)
 
 	def set(self, num: float) -> None:
 		"""SCPI: *RCL \n
