@@ -1,10 +1,10 @@
 """RsCMPX_Base instrument driver
-	:version: 4.0.7.9
+	:version: 4.0.140.19
 	:copyright: 2021 by Rohde & Schwarz GMBH & Co. KG
 	:license: MIT, see LICENSE for more details.
 """
 
-__version__ = '4.0.7.9'
+__version__ = '4.0.140.19'
 
 # Main class
 from RsCMPX_Base.RsCMPX_Base import RsCMPX_Base
@@ -18,6 +18,9 @@ from RsCMPX_Base.Internal.InstrumentErrors import RsInstrException, TimeoutExcep
 # Callback Event Argument prototypes
 from RsCMPX_Base.Internal.IoTransferEventArgs import IoTransferEventArgs
 
+# Logging Mode
+from RsCMPX_Base.Internal.ScpiLogger import LoggingMode
+
 # enums
 from RsCMPX_Base import enums
 
